@@ -701,31 +701,45 @@ back to the user from the mailer."
 		(save-excursion
 		  (set-buffer errbuf)
 		  (erase-buffer))))
-	  (let ((default-directory "/"))
-	    (apply 'call-process-region
-		   (append (list (point-min) (point-max)
-				 (if (boundp 'sendmail-program)
-				     sendmail-program
-				   "/usr/lib/sendmail")
-				 nil errbuf nil "-oi")
-			   ;; Always specify who from,
-			   ;; since some systems have broken sendmails.
-			   (list "-f" (user-login-name))
-;;;			 ;; Don't say "from root" if running under su.
-;;;			   (and (equal (user-real-login-name) "root")
-;;;				(list "-f" (user-login-name)))
-			   (and mail-alias-file
-				(list (concat "-oA" mail-alias-file)))
-			   ;; These mean "report errors by mail"
-			   ;; and "deliver in background".
-			   (if (null mail-interactive) '("-oem" "-odb"))
-			   ;; Get the addresses from the message
-			   ;; unless this is a resend.
-			   ;; We must not do that for a resend
-			   ;; because we would find the original addresses.
-			   ;; For a resend, include the specific addresses.
-			   (or resend-to-addresses
-			       '("-t")))))
+	  (let ((default-directory "/")
+		exit-value)
+	    (setq exit-value (apply 'call-process-region
+				    (append (list (point-min) (point-max)
+						  (if (boundp
+						       'sendmail-program)
+						      sendmail-program
+						    "/usr/lib/sendmail")
+						  nil errbuf nil "-oi")
+					    ;; Always specify who from,
+					    ;; since some systems have
+					    ;; broken sendmails.
+					    (list "-f" (user-login-name))
+;;;					    ;; Don't say "from root" if
+;;;					    ;; running under su.
+;;;					    (and (equal (user-real-login-name)
+;;;							"root")
+;;;						 (list "-f" (user-login-name)))
+					    (and mail-alias-file
+						 (list
+						  (concat "-oA"
+							  mail-alias-file)))
+					    ;; These mean "report errors by
+					    ;; mail" and "deliver in
+					    ;; background".
+					    (if (null mail-interactive)
+						'("-oem" "-odb"))
+					    ;; Get the addresses from the
+					    ;; message unless this is a
+					    ;; resend.  We must not do that
+					    ;; for a resend because we
+					    ;; would find the original
+					    ;; addresses.  For a resend,
+					    ;; include the specific
+					    ;; addresses.
+					    (or resend-to-addresses
+						'("-t")))))
+	    (if (not (or (eq errbuf 0) (zerop exit-value)))
+		(error "Sending...failed with exit value %d" exit-value)))
 	  (if mail-interactive
 	      (save-excursion
 		(set-buffer errbuf)
